@@ -15,6 +15,7 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, List, Type
 
+from botocore.client import ClientMeta
 from botocore.exceptions import ClientError as Boto3ClientError
 
 from mypy_boto3_qldb.type_defs import (
@@ -63,6 +64,7 @@ class QLDBClient:
     [QLDB.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/qldb.html#QLDB.Client)
     """
 
+    meta: ClientMeta
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
